import request, { getBaseUrl } from './request'

export function getUserProfile() {
    return request.get(`/user/profile`)
}

export function getUserInfo(uid) {
    return request.get(`/user/info/${uid}`)
}

export function userLogin(username, password) {
    let domain = 'test.cc.echo.me';
    if (process.env.NODE_ENV === 'production') {
        domain = window.location.hostname;
    }
    return request.post(`/passport/login`, {
        "domain": domain,
        "username": username,
        "password": password,
        "remember": true
    })
}

export function getUserTypes() {
    return request.get('/organize/user-types')
}

export function userLogout() {
    return request.delete('/passport/logout')
}

export function updateProfile(data) {
    return request.put('/organize/profile', data)
}

export function resetPassword(oldPwd, newPwd) {
    return request.put('/organize/password', {
        old_password: oldPwd,
        new_password: newPwd
    })
}

export function lastLogin() {
    return request.get('/organize/last-login');
}

export function getNestedDepartments() {
    return request.get('/organize/department-nested')
}

export function getDepartmentUsers(id) {
    return request.get(`/organize/department-users/${id}`)
}

export function getUsers(id) {
    return request.get(`/organize/user-list`)
}

export function getClientHello() {
    return request.post(`/organize/client-hello`)
}

export function getUserAvatar(uid) {
    return `${getBaseUrl()}/organize/avatar/${uid}`
}

export function setUserAttr(name, value) {
    let data = '';
    if (typeof value !== 'string') {
        try {
            data = JSON.stringify(value)
        } catch (e) {
            data = value
        }
    } else {
        data = value
    }
    return request.put(`/organize/user-variable`, {
        name: name,
        value: data,
    })
}

export function getUserAttr(name) {
    return new Promise((resolve, reject) => {
        request.get(`/organize/user-variable/${name}`).then(res => {
            if (res.value) {
                try {
                    let data = JSON.parse(res.value);
                    resolve(data);
                } catch (e) {
                    resolve(res.value)
                }
            } else {
                reject(new Error("not found"))
            }
        }).catch(e => {
            reject(e);
        })
    })
}

export function getUnreadMsgCount() {
    return request.get(`/organize/unread/count`)
}

export function readUserMsg(id) {
    return request.put(`/organize/notice-read/${id}`)
}

export function getDepartmentUserNested() {
    return request.put(`/organize/department-users`)
}

export function getStatusTypes() {
    return request.post(`/organize/status-types`)
}